Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: components/omnibox/browser/omnibox_field_trial.cc

Issue 2961393002: Omnibox UI Experiments: Hook up elide-after-host feature flag. (Closed)
Patch Set: merge Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/omnibox/browser/omnibox_field_trial.h ('k') | tools/metrics/histograms/enums.xml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/omnibox/browser/omnibox_field_trial.cc
diff --git a/components/omnibox/browser/omnibox_field_trial.cc b/components/omnibox/browser/omnibox_field_trial.cc
index 49596e8cdd0d0d7c61a407dfb03008e3ec58acab..6357182923211fa3d33cc51ef56ee78121111b84 100644
--- a/components/omnibox/browser/omnibox_field_trial.cc
+++ b/components/omnibox/browser/omnibox_field_trial.cc
@@ -103,9 +103,10 @@ const base::Feature kUIExperimentMaxAutocompleteMatches{
"OmniboxUIExperimentMaxAutocompleteMatches",
base::FEATURE_DISABLED_BY_DEFAULT};
-// Feature used for hiding the suggestion URL path as a UI experiment.
-const base::Feature kUIExperimentHideSuggestionUrlPath{
- "OmniboxUIExperimentHideSuggestionUrlPath",
+// Feature used for eliding the suggestion URL after the host as a UI
+// experiment.
+const base::Feature kUIExperimentElideSuggestionUrlAfterHost{
+ "OmniboxUIExperimentElideSuggestionUrlAfterHost",
base::FEATURE_DISABLED_BY_DEFAULT};
// Feature used for hiding the suggestion URL scheme as a UI experiment.
« no previous file with comments | « components/omnibox/browser/omnibox_field_trial.h ('k') | tools/metrics/histograms/enums.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698